@@ -1,4 +1,4 @@
-from django import template
+dfrom django import template
 import simplejson as json
 import datetime
 from knockout_modeler.ko import ko, koData, koModel, get_fields
@@ -15,9 +15,9 @@ def knockout(values):
         field_names = values[0].knockout_fields()
     else:
         try:
-            fields = values[0].to_dict().keys()
+            field_names = values[0].to_dict().keys()
         except Exception, e:
-            fields = values[0]._meta.fields
+            field_names = values[0]._meta.fields
 
     return ko(values, field_names)
 
@@ -30,7 +30,10 @@ def knockout_data(values):
     if hasattr(modelClass, "knockout_fields"):
         field_names = values[0].knockout_fields()
     else:
-        field_names = values[0].to_dict().keys()
+        try:
+            field_names = values[0].to_dict().keys()
+        except Exception, e:
+            field_names = values[0]._meta.fields
 
     return koData(values, field_names)
 
@@ -44,9 +47,9 @@ def knockout_model(values):
         field_names = values[0].knockout_fields()
     else:
         try:
-            fields = values[0].to_dict().keys()
+            field_names = values[0].to_dict().keys()
         except Exception, e:
-            fields = values[0]._meta.fields
+            field_names = values[0]._meta.fields
 
     return koModel(modelClass, field_names)
 
